<?php

namespace Drupal\email_confirmer;

use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Access\AccessResult;

/**
 * Access controller for the email confirmation entity.
 *
 * @see \Drupal\email_confirmer\Entity\EmailConfirmation.
 */
class EmailConfirmationAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\email_confirmer\EmailConfirmationInterface $entity */

    // IP access restriction.
    if (!$account->hasPermission('administer email confirmations')
      && \Drupal::config('email_confirmer.settings')->get('restrict_same_ip')
      && !$entity->get('ip')->isEmpty()
      && $entity->get('ip')->getString() != \Drupal::request()->getClientIp()) {
      return AccessResult::forbidden();
    }

    return AccessResult::allowedIfHasPermission('access email confirmation')->cachePerPermissions();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission('access email confirmation')->cachePerPermissions();
  }

}
